package com.ruoyi.doubledefense.service;

import java.util.List;

import com.github.pagehelper.PageInfo;
import com.ruoyi.doubledefense.domain.CheckTask;
import com.ruoyi.doubledefense.dto.CheckTaskDTO;
import com.ruoyi.doubledefense.dto.res.CheckTaskResultDTO;
import com.ruoyi.doubledefense.dtoGov.CheckTaskDTOGov;

/**
 * 隐患排查任务Service接口
 *
 * @author ruoyi
 * @date 2023-08-03
 */
public interface ICheckTaskService {
    /**
     * 重预防汇聚计算节点
     * 查询隐患排查要求
     *
     * @param checkTaskDTOGov
     * @return
     */
    PageInfo<CheckTaskDTOGov> govSelectCheckTaskList(CheckTaskDTOGov checkTaskDTOGov);

    /**
     * 查询隐患排查任务
     *
     * @param id 隐患排查任务主键
     * @return 隐患排查任务
     */
    public CheckTaskResultDTO selectCheckTaskById(String id);

    /**
     * 查询隐患排查任务列表
     *
     * @param checkTaskDTO 隐患排查任务
     * @return 隐患排查任务集合
     */
    public List<CheckTaskResultDTO> selectCheckTaskList(CheckTaskDTO checkTaskDTO);

    /**
     * 新增隐患排查任务
     *
     * @param checkTask 隐患排查任务
     * @return 结果
     */
    public int insertCheckTask(CheckTaskDTO checkTask);

    /**
     * 修改隐患排查任务
     *
     * @param checkTask 隐患排查任务
     * @return 结果
     */
    public int updateCheckTask(CheckTaskDTO checkTask);

    /**
     * 批量删除隐患排查任务
     *
     * @param ids 需要删除的隐患排查任务主键集合
     * @return 结果
     */
    public int deleteCheckTaskByIds(String[] ids);
}
